@@ -479,7 +479,7 @@ gps_mask_t PrintSERPacket(struct gps_device_t *session, unsigned char pkt_id,
                      "Garmin: Alt: %.3f, sep: %.3f, eph: %.3f, Epv: %.3f, "
                      "Fix: %d, Gps_tow: %f, Lat: %.3f, Lon: %.3f, "
                      "velN: %.3f, velE: %.3f, velD: %.3f, geoidsep: %.3f, "
-                     "Leap: %d, GarminDays: %d\n",
+                     "Leap: %d, GarminDays: %ld\n",
                      session->newdata.altHAE,
                      session->newdata.sep,
                      session->newdata.eph,
@@ -531,7 +531,7 @@ gps_mask_t PrintSERPacket(struct gps_device_t *session, unsigned char pkt_id,
                  GPSD_LED64(rmd->rcvr_tow), GPSD_LE16TOH(rmd->rcvr_wn));
         for (i = 0; i < GARMIN_CHANNELS; i++) {
             GPSD_LOG(LOG_INF, &session->context->errout,
-                     "Garmin: PVT RMD Sat: %3u, cycles: %9u, pr: %16.6f, "
+                     "Garmin: PVT RMD Sat: %3u, cycles: %9lu, pr: %16.6f, "
                      "phase: %7.3f, slp_dtct: %3s, snr: %3u, Valid: %3s\n",
                      (int)rmd->sv[i].svid + 1,
                      GPSD_LE32TOH(rmd->sv[i].cycles),
@@ -992,7 +992,8 @@ static void garmin_event_hook(struct gps_device_t *session, event_t event)
      * FIX-ME: It might not be necessary to call this on reactivate.
      * Experiment to see if the holds its settings through a close.
      */
-    if (event == event_identified || event == event_reactivate) {
+    if (event == EVENT_IDENTIFIED ||
+        event == EVENT_REACTIVATE) {
         // Tell the device to send product data
         GPSD_LOG(LOG_PROG, &session->context->errout,
                  "Garmin: Get Product Data\n");
@@ -1016,10 +1017,11 @@ static void garmin_event_hook(struct gps_device_t *session, event_t event)
                               CMND_START_RM_DATA);
 #endif
     }
-    if (event == event_deactivate)
+    if (event == EVENT_DEACTIVATE) {
         // FIX-ME: is any action needed, or is closing the port sufficient?
         GPSD_LOG(LOG_PROG, &session->context->errout,
                  "Garmin: garmin_close()\n");
+    }
 }
 
 #define Send_ACK()    Build_Send_SER_Packet(session, 0, ACK, 0, 0)
@@ -1261,7 +1263,7 @@ const struct gps_type_t driver_garmin_usb_binary =
     .trigger        = NULL,                 // no trigger, it has a probe
     .channels       = GARMIN_CHANNELS,      // consumer-grade GPS
     .probe_detect   = garmin_usb_detect,    // how to detect at startup time
-    .get_packet     = generic_get,          // how to grab a packet
+    .get_packet     = packet_get1,          // how to grab a packet
     .parse_packet   = garmin_ser_parse,     // parse message packets
     .rtcm_writer    = NULL,                 // don't send DGPS corrections
     .init_query     = NULL,                 // non-perturbing initial query
@@ -1283,7 +1285,7 @@ const struct gps_type_t driver_garmin_ser_binary =
     .trigger        = NULL,                    // no trigger, it has a probe
     .channels       = GARMIN_CHANNELS,         // consumer-grade GPS
     .probe_detect   = NULL,                    // how to detect at startup time
-    .get_packet     = generic_get,             // how to grab a packet
+    .get_packet     = packet_get1,             // how to grab a packet
     .parse_packet   = garmin_ser_parse,        // parse message packets
     .rtcm_writer    = NULL,                    // don't send DGPS corrections
     .init_query     = NULL,                    // non-perturbing initial query
